fisx: Member List

fisx

fisx::XRFConfig Member List

This is the complete list of members for fisx::XRFConfig, including all inherited members.

addCollimator() (defined in fisx::XRFConfig) | fisx::XRFConfig |
getAlphaIn() const (defined in fisx::XRFConfig) | fisx::XRFConfig | inline
getAlphaOut() const (defined in fisx::XRFConfig) | fisx::XRFConfig | inline
getAttenuators() const (defined in fisx::XRFConfig) | fisx::XRFConfig | inline
getBeam() const | fisx::XRFConfig |
getBeamFilters() const (defined in fisx::XRFConfig) | fisx::XRFConfig | inline
getDetector() const (defined in fisx::XRFConfig) | fisx::XRFConfig | inline
getReferenceLayer() const (defined in fisx::XRFConfig) | fisx::XRFConfig | inline
getSample() const (defined in fisx::XRFConfig) | fisx::XRFConfig | inline
getScatteringAngle() const (defined in fisx::XRFConfig) | fisx::XRFConfig | inline
getUserAttenuators() const (defined in fisx::XRFConfig) | fisx::XRFConfig | inline
getUserBeamFilters() const (defined in fisx::XRFConfig) | fisx::XRFConfig | inline
operator<< (defined in fisx::XRFConfig) | fisx::XRFConfig | friend
readConfigurationFromFile(const std::string &fileName) (defined in fisx::XRFConfig) | fisx::XRFConfig |
saveConfigurationToFile(const std::string &fileName) (defined in fisx::XRFConfig) | fisx::XRFConfig |
setAttenuators(const std::vector< Layer > &attenuators) | fisx::XRFConfig |
setAttenuators(const std::vector< std::string > &names, const std::vector< double > &densities, const std::vector< double > &thicknesses, const std::vector< std::string > &comments) (defined in fisx::XRFConfig) | fisx::XRFConfig |
setBeam(const double &energy, const double &divergency) | fisx::XRFConfig |
setBeam(const std::vector< double > &energies, const std::vector< double > &weight, const std::vector< int > &characteristic=std::vector< int >(), const std::vector< double > &divergency=std::vector< double >()) (defined in fisx::XRFConfig) | fisx::XRFConfig |
setBeam(const Beam &beam) (defined in fisx::XRFConfig) | fisx::XRFConfig |
setBeamFilters(const std::vector< std::string > &names, const std::vector< double > &densities, const std::vector< double > &thicknesses, const std::vector< std::string > &comments) | fisx::XRFConfig |
setBeamFilters(const std::vector< Layer > &filters) (defined in fisx::XRFConfig) | fisx::XRFConfig |
setCollimators() | fisx::XRFConfig |
setDetector(const Detector &detector) | fisx::XRFConfig |
setGeometry(const double &alphaIn, const double &alphaOut, const double &scatteringAngle=90.) | fisx::XRFConfig |
setReferenceLayer(int referenceLayer) | fisx::XRFConfig |
setSample(const std::vector< Layer > &layers, const int &referenceLayer=0) | fisx::XRFConfig |
setSample(const std::vector< std::string > &names, const std::vector< double > &densities, const std::vector< double > &thicknesses, const std::vector< std::string > &comments, const int &referenceLayer=0) (defined in fisx::XRFConfig) | fisx::XRFConfig |
setUserAttenuators(const std::vector< TransmissionTable > &userAttenuators) | fisx::XRFConfig |
setUserBeamFilters(const std::vector< TransmissionTable > &userBeamFilters) | fisx::XRFConfig |
XRFConfig() (defined in fisx::XRFConfig) | fisx::XRFConfig |